
%global pkg_name text-icu
%global pkgver %{pkg_name}-%{version}


Name:           ghc-%{pkg_name}
Version:        0.8.0.4
Release:    1%{?dist}
Summary:        Bindings to the ICU library

License:        BSD-3-Clause
Url:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkgver}/%{pkgver}.tar.gz

BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
%if %{with ghc_prof}
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-deepseq-prof
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-time-prof
%endif
BuildRequires:  libicu-devel
BuildRequires:  pkgconfig(icu-i18n)

%description
Haskell bindings to the International Components for Unicode (ICU) libraries.
These libraries provide robust and full-featured Unicode services on a wide
variety of platforms.

Features include:

* Both pure and impure bindings, to allow for fine control over efficiency and
ease of use.

* Breaking of strings on character, word, sentence, and line boundaries.

* Access to the Unicode Character Database (UCD) of character metadata.

* String collation functions, for locales where the conventions for
lexicographic ordering differ from the simple numeric ordering of character
codes.

* Character set conversion functions, allowing conversion between Unicode and
over 220 character encodings.

* Unicode normalization. (When implementations keep strings in a normalized
form, they can be assured that equivalent strings have a unique binary
representation.)

* Regular expression search and replace.

* Security checks for visually confusable (spoofable) strings.

* Bidirectional Unicode algorithm

* Calendar objects holding dates and times.

* Number and calendar formatting.


%package devel
Summary:        Haskell %{pkg_name} library development files
Provides:       %{name}-static = %{version}-%{release}
Provides:       %{name}-static = %{version}-%{release}
%if %{defined ghc_version}
Requires:       ghc-compiler = %{ghc_version}
%endif
Requires:       %{name} = %{version}-%{release}
Requires:       libicu-devel
Requires:       pkgconfig(icu-i18n)

%description devel
This package provides the Haskell %{pkg_name} library development files.


%if %{with haddock}
%package doc
Summary:        Haskell %{pkg_name} library documentation
BuildArch:      noarch
Requires:       ghc-filesystem

%description doc
This package provides the Haskell %{pkg_name} library documentation.
%endif


%if %{with ghc_prof}
%package prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       %{name}-devel = %{version}-%{release}
Supplements:    (%{name}-devel and ghc-prof)

%description prof
This package provides the Haskell %{pkg_name} profiling library.
%endif


%prep
%setup -q -n %{pkgver}


%build
%ghc_lib_build


%install
%ghc_lib_install


%files -f %{name}.files
%license LICENSE


%files devel -f %{name}-devel.files
%doc README.markdown changelog.md


%if %{with haddock}
%files doc -f %{name}-doc.files
%license LICENSE
%endif


%if %{with ghc_prof}
%files prof -f %{name}-prof.files
%endif


%changelog
* Thu Aug 08 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.8.0.4-1
- initial build
